
.. |configuring_blank_lines_link| replace::
   Refer to :ref:`configuring-blank-lines` for more information.

.. |configuring_block_comments_link| replace::
   Refer to :ref:`configuring-block-comments` for more information.

.. |configuring_conditional_multiline_indent_rules_link| replace::
   Refer to :ref:`configuring-conditional-multiline-indent-rules` for more information.

.. |configuring_consecutive_blank_line_rules| replace::
   Refer to :ref:`configuring-consecutive-blank-line-rules` for more information.

.. |configuring_disabled_rules_link| replace::
   Refer to :ref:`configuring-disabled-rules` for more information.

.. |configuring_identifier_alignment_rules_link| replace::
   Refer to :ref:`configuring-identifier-alignment-rules` for more information.

.. |configuring_indentation_link| replace::
   Refer to :ref:`configuring-indentation` for more information.

.. |configuring_keyword_alignment_rules_link| replace::
   Refer to :ref:`configuring-keyword-alignment-rules` for information on changing the configurations.

.. |configuring_length_rules_link| replace::
   Refer to :ref:`configuring-length-rules` for more information.

.. |configuring_move_token_rules_link| replace::
   Refer to :ref:`configuring-move-token-rules` for more information.

.. |configuring_multiline_indent_rules_link| replace::
   Refer to :ref:`configuring-multiline-indent-rules` for more information.

.. |configuring_selected_assignment_structure_rules_link| replace::
   Refer to :ref:`configuring-selected-assignment-structure-rules` for more information.

.. |configuring_simple_multiline_structure_rules_link| replace::
   Refer to :ref:`configuring-simple-multiline-structure-rules` for more information.

.. |configuring_array_multiline_structure_rules_link| replace::
   Refer to :ref:`configuring-array-multiline-structure-rules` for more information.

.. |configuring_multiline_constraint_rules_link| replace::
   Refer to :ref:`configuring-multiline-constraint-rules` for more information.

.. |configuring_multiline_report_rule_link| replace::
   Refer to :ref:`configuring-multiline-report-rule` for more information.

.. |configuring_number_of_signals_in_signal_declaration_link| replace::
   Refer to :ref:`configuring-number-of-signals-in-signal-declaration` for more information.

.. |configuring_optional_items_link| replace::
   Refer to :ref:`configuring-optional-items` for more information.

.. |configuring_port_mode_alignment_link| replace::
   Refer to :ref:`configuring-port-mode-alignment` for more information.

.. |configuring_prefix_and_suffix_rules_link| replace::
   Refer to :ref:`configuring-prefix-and-suffix-rules` for more information.

.. |configuring_previous_line_rules_link| replace::
   Refer to :ref:`configuring-previous-line-rules` for more information.

.. |configuring_type_of_instantiations_link| replace::
   Refer to :ref:`configuring-type-of-instantiations` for more information.

.. |configuring_uppercase_and_lowercase_rules_link| replace::
   Refer to :ref:`configuring-uppercase-and-lowercase-rules` for more information.

.. |configuring_whitespace_rules_link| replace::
   Refer to :ref:`configuring-whitespace-rules` for options on changing the number of whitespaces..

.. |configuring_whitespace_after_comment_rules_link| replace::
   Refer to :ref:`configuring-whitespace-after-comment-rules` for information on creating exceptions to this rule.

.. |configuring_comment_keywords_link| replace::
   Refer to :ref:`configuring-comment-keywords` for information on how to change the search comment keywords.

.. |configuring_use_clause_indenting_link| replace::
   Refer to :ref:`configuring-use-clause-indenting` for information on how to change the indenting of use clauses.

.. |configuring_pragmas_link| replace::
   Refer to :ref:`configuring-pragmas` for information on how to configure detecting of pragmas.

.. |configuring_vhdl_reserved_words_link| replace::
   Refer to :ref:`configuring-vhdl-reserved-words` for information on how to change which VHDL standard reserved words to use.

.. |configuring_multiline_procedure_call_statement_rules_link| replace::
   Refer to :ref:`configuring-procedure-call-statement-rules` for more configuration options.

.. |configuring_subprogram_specification_statement_rules_link| replace::
   Refer to :ref:`configuring-subprogram-specification-statement-rules` for more configuration options.

.. |configuring_port_map_new_line_link| replace::
   Refer to :ref:`configuring-port-map-new-line` for configuration options.
